<?php

/**
* Data Transaction / PostgreSQL Plugin
* A PostgreSQL plugin to the (data_trans) class
* @package		phpOpenFW
* @subpackage 	Database_Tools
* @author 		Christian J. Clark
* @copyright	Copyright (c) Christian J. Clark
* @license		http://www.gnu.org/licenses/gpl-2.0.txt
* @access		private
* @version 		Started: 2-1-2007 updated: 1-20-2010
*/

//***************************************************************
/**
 * dt_pgsql Class
 * @package		phpOpenFW
 * @subpackage	Database_Tools
 * @access		private
 */
//***************************************************************
class dt_pgsql extends dt_structure
{
    
    /**
	* Opens a connection to the specified data source based on the data source type
	**/
	//*************************************************************************
	// Make a connection to the given source and store the handle
	//*************************************************************************
	public function open()
	{
		if (!$this->port) { $this->port = 5432; }
		$str_conn = "host=$this->server port=$this->port dbname=$this->source user=$this->user password=$this->pass";
        $this->handle = pg_connect($str_conn);

        if (!$this->handle) {
            $this->connection_error(pg_last_error());
            return false;
        }
		else {
			// Flag Connection as Open       
	        $this->conn_open = true;
	        return true;
		}
	}
	
	/**
	* Closes a connection to the specified data source based on the data source type
	**/
	//*************************************************************************
	// Close the connection to the data source
	//*************************************************************************
    public function close()
	{
	   if ($this->handle) { pg_close($this->handle); }
	   $this->conn_open = false;
	}
	
	/**
	* Executes a query based on the data source type
	* @param mixed PostgreSQL: SQL Statement
	**/
	//*************************************************************************
	// Execute a query and store the record set
	//*************************************************************************
	public function query($query)
	{
		// Check for Open Connection
		if (!$this->is_open()) { return false; }

        $this->rsrc_id = pg_query($query);
        if ($this->rsrc_id) {
            $this->num_rows = pg_num_rows($this->rsrc_id);
            while($row=pg_fetch_assoc($this->rsrc_id)){
                array_push($this->result, $row);
            }
        }
        
        // Last Insert ID
        if (count($this->result) == 1 && count($this->result[0]) == 1 && key($this->result[0]) == 'id') {
            $this->last_id = $this->result[0]['id'];
        }
        
        // PgSQL Error Reporting
        if ($pgsql_error=pg_last_error()) { $this->gen_error($pgsql_error); }
	}

}

?>
